MilvusVectorStore

Struct MilvusVectorStore 

pub struct MilvusVectorStore<M> { /* private fields */ }
Represents a vector store implementation using Milvus - https://milvus.io/ as the backend.

Implementations

Source

impl<M> MilvusVectorStore<M>
where M: EmbeddingModel,

pub fn new( model: M, base_url: String, database_name: String, collection_name: String, ) -> Self

Creates a new instance of MilvusVectorStore.

Arguments
  • model - Embedding model instance
  • base_url - The URL of where your Milvus instance is located. Alternatively if you’re using the Milvus offering provided by Zilliz, your cluster endpoint.
  • database_name - The name of your database
  • collection_name - The name of your collection
pub fn auth(self, username: String, password: String) -> Self

Forms the auth token for Milvus from your username and password. Required if using a Milvus instance that requires authentication.